#!/bin/sh
#  _    _          ___           __ _     (R)
# | |  (_)_ _____ / __|___ _ _  / _(_)__ _
# | |__| \ V / -_) (__/ _ \ ' \|  _| / _` |
# |____|_|\_/\___|\___\___/_||_|_| |_\__, |
#                                    |___/
# Copyright (c) 2009-2024 LiveConfig GmbH.
# ----------------------------------------------------------------------------
# Send warning message when a user exceeds his mailbox quota
# ----------------------------------------------------------------------------

PERCENT=$1
[ -n "$2" ] && USER=$2
DATE=$(date -R)
TEMPLATE=/etc/liveconfig/mailquota.txt

# Search for dovecot "deliver" tool:
for name in /usr/lib/dovecot/dovecot-lda /usr/lib/dovecot/deliver /usr/libexec/dovecot/dovecot-lda /usr/libexec/dovecot/deliver; do
    if [ -x "$name" ]; then
        DELIVER=$name
        break
    fi
done
[ -z "$DELIVER" ] && echo "mailquota.sh: no deliver tool found" >&2 && exit 1

# Check all other prerequisites:
[ -f "$TEMPLATE" ] || exit 1
[ -n "$USER" ] || exit 1

OPTIONS=""
if [ -z "$2" ]; then
    # Dovecot 1.x
    # Search for configuration file
    for name in /etc/dovecot/dovecot.conf.noquota /etc/dovecot.conf.noquota; do
        if [ -f "$name" ]; then
            CONFIG=$name
            break
        fi
    done
    [ -z "$CONFIG" ] && echo "mailquota.sh: configuration file 'dovecot.conf.noquota' not found" >&2 && exit 1
    OPTIONS="-c $CONFIG"
else
    # Dovecot 2.x
    OPTIONS="-o \"plugin/quota=maildir:User quota:noenforcing\""
fi

logger -t quotawarn -i -p mail.info "action=mailbox, user=$USER, percent=$PERCENT"

sed -e "s/%USER%/$USER/g" \
    -e "s/%PERCENT%/$PERCENT/g" \
    -e "s/%DATE%/$DATE/g" \
    $TEMPLATE \
    | eval $DELIVER -d "${USER}" "${OPTIONS}"

# <EOF>-----------------------------------------------------------------------
